@@ -13,10 +13,10 @@ from pinocchio.visualize import GepettoVisualizer
 # Conversion with str seems to be necessary when executing this file with ipython
 pinocchio_model_dir = join(dirname(dirname(str(abspath(__file__)))),"models")
 
-model_path = join(pinocchio_model_dir,"others/robots")
-mesh_dir = model_path
+model_path = join(pinocchio_model_dir,"example-robot-data/robots")
+mesh_dir = pinocchio_model_dir
 urdf_filename = "talos_reduced.urdf"
-urdf_model_path = join(join(model_path,"talos_data/urdf"),urdf_filename)
+urdf_model_path = join(join(model_path,"talos_data/robots"),urdf_filename)
 
 model, collision_model, visual_model = pin.buildModelsFromUrdf(urdf_model_path, mesh_dir, pin.JointModelFreeFlyer())
 viz = GepettoVisualizer(model, collision_model, visual_model)
