@@ -478,6 +478,16 @@ namespace pinocchio
 
     JointDataDerived createData() const { return JointDataDerived(); }
     
+    const std::vector<bool> hasConfigurationLimit() const
+    {
+      return {true, true, false, false};
+    }
+
+    const std::vector<bool> hasConfigurationLimitInTangent() const
+    {
+      return {true, true, false};
+    }
+
     template<typename ConfigVector>
     inline void forwardKinematics(Transformation_t & M, const Eigen::MatrixBase<ConfigVector> & q_joint) const
     {
