@@ -414,12 +414,22 @@ namespace pinocchio
 
     JointDataDerived createData() const { return JointDataDerived(); }
 
+    const std::vector<bool> hasConfigurationLimit() const
+    {
+      return {false, false, false, false};
+    }
+
+    const std::vector<bool> hasConfigurationLimitInTangent() const
+    {
+      return {false, false, false};
+    }
+
     template<typename ConfigVectorLike>
     inline void forwardKinematics(Transformation_t & M, const Eigen::MatrixBase<ConfigVectorLike> & q_joint) const
     {
       typedef typename ConfigVectorLike::Scalar Scalar;
       EIGEN_STATIC_ASSERT_SAME_VECTOR_SIZE(ConfigVector_t,ConfigVectorLike);
-      typedef typename Eigen::Quaternion<typename ConfigVectorLike::Scalar,PINOCCHIO_EIGEN_PLAIN_TYPE(ConfigVectorLike)::Options> Quaternion;
+      typedef typename Eigen::Quaternion<Scalar,PINOCCHIO_EIGEN_PLAIN_TYPE(ConfigVectorLike)::Options> Quaternion;
       typedef Eigen::Map<const Quaternion> ConstQuaternionMap;
 
       ConstQuaternionMap quat(q_joint.derived().data());
